<?php

namespace Schaffen\Gef\Services;

use App\Http\Controllers\Api\Ged\DocumentoModuloService;
use App\Http\Services\Estoque\LocaisEstoque\LocalEstoqueService;
use App\Http\Utils\SCHArray;
use App\Models\Estoque\Cadastro\LocalEstoque;
use Schaffen\Gef\Models\Veiculo;
use Schaffen\Gef\Repositories\VeiculoRepository;
use Schaffen\Gef\Validators\VeiculoValidator;
use Prettus\Validator\Exceptions\ValidatorException;

class VeiculoService
{

   private $repository;
   private $validator;

   public function __construct(VeiculoRepository $repository, VeiculoValidator $validator)
   {
      $this->repository = $repository;
      $this->validator = $validator;
   }

   public function updateOrCreate($data, $codigo = null)
   {
      try {

         $documentos = $data;
         $attrib = ['vei_codigo' => $codigo];

         $validator_rules = is_numeric($codigo) ? VeiculoValidator::RULE_UPDATE : VeiculoValidator::RULE_CREATE;
         $this->validator->with($data)->passesOrFail($validator_rules);
         $this->repository->setPresenter("Schaffen\\Gef\\Presenters\\VeiculoPresenter");

         $data['fk_seguradora_pes_codigo'] = isset($data['seguradora']) ? $data['seguradora'] : null;
         $data['fk_proprietario_pes_codigo'] = isset($data['proprietario']) ? $data['proprietario'] : null;

         $data = SCHArray::addPrefix(Veiculo::$prefix, $data);
         $local_estoque_data = [
            'loe_descricao' => $data['vei_identificador'],
            'loe_tipo'      => LocalEstoque::LOCAL_VEICULO
         ];

         $local_estoque_service = new LocalEstoqueService();
         $data['vei_fk_loe_codigo'] = $local_estoque_service->updateOrCreate($local_estoque_data)->loe_codigo;

         $veiculo = $this->repository->updateOrCreate($attrib, $data);

         //trata as informações de documentos do módulo
         DocumentoModuloService::trataObjetoDocumentoModulo(
            $documentos,
            $veiculo['data']['codigo'],
            DocumentoModuloService::MODULO_VEICULO
         );



         $response = [
            'status' => true,
            'errors' => '',
            'message' => 'Veiculo gravado',
            'data' => $veiculo['data'],
            'http_code' => '200'
         ];


         return $response;

      } catch (ValidatorException $e) {
         return $response = [
            'status' => false,
            'errors' => $e->getMessageBag(),
            'message' => 'Não foi possível gravar o veículo',
            'data' => null,
            'http_code' => '400'
         ];
      }
   }
}
